@@ -8,8 +8,7 @@ from PyQt5 import QtGui
 import pyqtgraph as pg
 import datetime
 import pynwb
-import nwbext_ecog
-from ecogvis.functions.htk_to_nwb.chang2nwb import chang2nwb
+import ndx_ecog
 
 
 class TimeSeriesPlotter:
@@ -18,23 +17,22 @@ class TimeSeriesPlotter:
     It also holds information of the currently open NWB file, as well as user
     annotations and intervals.
     """
-    def __init__(self, par, htk_config=None):
+    def __init__(self, par):
         self.parent = par
         self.source_path = Path(par.source_path)
 
-        # Makes nwbfile object from nwb file or from HTK directory
+        # Makes nwbfile object from nwb file
         if self.source_path.is_file():
-            self.subject_id = self.source_path.name.split('_')[0][2:]
-            self.block = self.source_path.name.split('_')[1][1:-4]
+            if '_' in self.source_path.name:
+                self.subject_id = self.source_path.name.split('_')[0][2:]
+                self.block = self.source_path.name.split('_')[1][1:-4]
+            else:
+                self.subject_id = ''
+                self.block = ''
             self.io = pynwb.NWBHDF5IO(str(self.source_path), 'r+', load_namespaces=True)
             self.nwb = self.io.read()      # reads NWB file
-        elif self.source_path.is_dir():
-            self.nwb, self.source_path, self.subject_id, self.block = chang2nwb(
-                blockpath=str(par.source_path),
-                save_to_file=True,
-                htk_config=htk_config,
-            )
-            self.parent.source_path = self.source_path.absolute()
+        else:
+            raise TypeError("Invalid file type")
 
         title = ' '.join(['EcogVIS -', self.parent.current_session,
                           self.source_path.name, '-', self.block])
@@ -68,19 +66,25 @@ class TimeSeriesPlotter:
             self.parent.push7_0.setEnabled(False)
         except:
             print("No 'high_gamma' data in 'processing' group.")
+
         self.plotData = self.source.data
         self.fs_signal = self.source.rate     # sampling frequency [Hz]
         self.tbin_signal = 1 / self.fs_signal  # time bin duration [seconds]
         self.nBins = self.source.data.shape[0]     # total number of bins
-        self.nChTotal = self.source.data.shape[1]     # total number of channels
-        self.allChannels = np.arange(0, self.nChTotal)  # array with all channels
+        self.min_window_bins = 10                   # minimum number of bins to plot
+        # Electrodes table - bipolar or regular table
+        self.electrodes_table = self.source.electrodes.table
+        # all electricalseries channels ids
+        self.all_channels_ids = self.electrodes_table.id[:]
+        self.electrical_series_channel_ids = np.array(self.all_channels_ids)[self.source.electrodes.data[:]].tolist()
+        self.n_channels_total = len(self.electrical_series_channel_ids)     # total number of channels
 
         # Get Brain regions present in current file
-        self.all_regions = list(set(list(self.nwb.electrodes['location'][:])))
+        self.all_regions = list(self.electrodes_table['location'][self.electrical_series_channel_ids])
         self.all_regions.sort()
         self.regions_mask = [True] * len(self.all_regions)
 
-        self.channels_mask = np.ones(len(self.nwb.electrodes['location'][:]))
+        self.channels_mask = np.ones(len(list(self.electrodes_table['location'][self.electrical_series_channel_ids])))
         self.channels_mask_ind = np.where(self.channels_mask)[0]
 
         self.h = []
@@ -92,16 +96,19 @@ class TimeSeriesPlotter:
 
         # Channels to show
         self.firstCh = int(self.parent.qline1.text())
-        self.lastCh = min(self.nChTotal, int(self.parent.qline0.text()))
+        self.lastCh = min(self.n_channels_total, int(self.parent.qline0.text()))
         self.parent.qline0.setText(str(self.lastCh))
         self.nChToShow = self.lastCh - self.firstCh + 1
         self.selectedChannels = np.arange(self.firstCh - 1, self.lastCh)
 
         self.current_rect = []
-        if 'bad' in self.nwb.electrodes:
-            self.badChannels = np.where(self.nwb.electrodes['bad'][:])[0].tolist()
+
+        # List of bad channels
+        if 'bad' in self.electrodes_table:
+            aux_mask = self.electrodes_table[self.electrical_series_channel_ids]['bad']
+            self.bad_channels_ids = list(self.electrodes_table[self.electrical_series_channel_ids][aux_mask].index)
         else:
-            self.badChannels = []
+            self.bad_channels_ids = []
 
         # Load invalid intervals from NWB file
         self.allIntervals = []
@@ -136,6 +143,34 @@ class TimeSeriesPlotter:
             c.setBrush(QtGui.QColor(255, 0, 0, 120))
             self.parent.win1.addItem(c)
 
+        # Test if current nwb file contains Survey table
+        if 'behavior' in self.nwb.processing:
+            list_surveys = [v for v in self.nwb.processing['behavior'].data_interfaces.values()
+                            if v.neurodata_type == 'SurveyTable']
+            if len(list_surveys) > 0:
+                self.parent.action_vis_survey.setEnabled(True)
+                self.parent.action_add_survey.setEnabled(False)
+            else:
+                self.parent.action_vis_survey.setEnabled(False)
+                self.parent.action_add_survey.setEnabled(True)
+        else:
+            self.parent.action_vis_survey.setEnabled(False)
+            self.parent.action_add_survey.setEnabled(True)
+
+        # Test if current nwb file contains Transcription tables
+        if 'behavior' in self.nwb.processing:
+            list_transcripts = [v for v in self.nwb.processing['behavior'].data_interfaces.values()
+                                if v.name in ['phonemes', 'syllables', 'words', 'sentences']]
+            if len(list_transcripts) > 0:
+                self.parent.transcriptionadd_tools_menu.setEnabled(False)
+                self.parent.action_vis_transcription.setEnabled(True)
+            else:
+                self.parent.transcriptionadd_tools_menu.setEnabled(True)
+                self.parent.action_vis_transcription.setEnabled(False)
+        else:
+            self.parent.transcriptionadd_tools_menu.setEnabled(True)
+            self.parent.action_vis_transcription.setEnabled(False)
+
         # Add Speaker and Mic Intervals if they exist
         self.SpeakerAndMicIntervalAdd()
 
@@ -246,7 +281,8 @@ class TimeSeriesPlotter:
         # Iterate over chosen channels, plot one at a time
         nrows, ncols = np.shape(plotData)
         for i in range(nrows):
-            if self.selectedChannels[i] in self.badChannels:
+            elec_index = self.source.electrodes[int(self.selectedChannels[i])].index[0]
+            if elec_index in self.bad_channels_ids:
                 plt2.plot(timebaseGuiUnits, plotData[i], pen=pg.mkPen((220, 0, 0), width=1.2))
             else:
                 c = pg.mkPen((0, 120, 0), width=1.2)
@@ -255,7 +291,7 @@ class TimeSeriesPlotter:
                 plt2.plot(timebaseGuiUnits, plotData[i], pen=c)
         plt2.setLabel('bottom', 'Time', units='sec')
         plt2.setLabel('left', 'Channel #')
-        labels = [str(ch + 1) for ch in self.selectedChannels]
+        labels = [str(self.electrical_series_channel_ids[ch]) for ch in self.selectedChannels]
         ticks = list(zip(self.scaleVec, labels))
         plt2.getAxis('left').setTicks([ticks])
         plt2.setXRange(timebaseGuiUnits[0], timebaseGuiUnits[-1], padding=0.003)
@@ -313,6 +349,7 @@ class TimeSeriesPlotter:
         # Bottom plot - Stimuli
         plt3 = self.parent.win3
         plt3.clear()
+        stimData = None
         if self.parent.combo4.currentText() != '':
             try:
                 xmask = (self.stimX > timebaseGuiUnits[0]) * (self.stimX < timebaseGuiUnits[-1])
@@ -327,6 +364,8 @@ class TimeSeriesPlotter:
                 plt3.plot(stimData, pen='k', width=1)
                 # remove this later -------------------------------------------
 
+        if stimData is not None:
+            plt3.setYRange(np.min(stimData), np.max(stimData))
         plt3.setLabel('left', 'Stim')
         plt3.getAxis('left').setWidth(w=53)
         plt3.getAxis('left').setStyle(showValues=False)
@@ -351,7 +390,7 @@ class TimeSeriesPlotter:
         self.intervalLengthGuiUnits = float(self.parent.qline3.text())
 
         max_dur = self.nBins * self.tbin_signal  # Max duration in seconds
-        min_len = 500 * self.tbin_signal          # Min accepted length
+        min_len = self.min_window_bins * self.tbin_signal          # Min accepted length
 
         # Check for max and min allowed values: START
         if self.intervalStartGuiUnits < 0.001:
@@ -374,7 +413,7 @@ class TimeSeriesPlotter:
         # Updates times in samples
         self.intervalLengthSamples = int(np.floor(self.intervalLengthGuiUnits / self.tbin_signal))
         self.intervalStartSamples = max(np.floor(self.intervalStartGuiUnits / self.tbin_signal), 0)
-        self.intervalStartSamples = int(min(self.intervalStartSamples, self.nBins - 501))
+        self.intervalStartSamples = int(min(self.intervalStartSamples, self.nBins - self.min_window_bins))
         self.intervalEndSamples = self.intervalStartSamples + self.intervalLengthSamples
 
         self.refreshScreen()
@@ -411,12 +450,12 @@ class TimeSeriesPlotter:
     def channel_Scroll_Up(self, opt='unit'):
         """Updates the channels to be plotted. Buttons: ^, ^^ """
         # Test upper limit
-        if self.lastCh < self.nChTotal:
+        if self.lastCh < self.n_channels_total:
             if opt == 'unit':
                 step = 1
             elif opt == 'page':
-                step = np.minimum(self.nChToShow, self.nChTotal - self.lastCh)
-            # Add +1 to first and last channels
+                step = np.minimum(self.nChToShow, self.n_channels_total - self.lastCh)
+            # Add to first and last channels
             self.firstCh += step
             self.lastCh += step
             self.parent.qline0.setText(str(self.lastCh))
@@ -451,15 +490,15 @@ class TimeSeriesPlotter:
         if self.firstCh < 1:
             self.firstCh = 1
 
-        if self.firstCh > self.nChTotal:
-            self.firstCh = self.nChTotal
-            self.lastCh = self.nChTotal
+        if self.firstCh > self.n_channels_total:
+            self.firstCh = self.n_channels_total
+            self.lastCh = self.n_channels_total
 
         if self.lastCh < 1:
             self.lastCh = self.firstCh
 
-        if self.lastCh > self.nChTotal:
-            self.lastCh = self.nChTotal
+        if self.lastCh > self.n_channels_total:
+            self.lastCh = self.n_channels_total
 
         if self.lastCh - self.firstCh < 1:
             self.lastCh = self.firstCh
@@ -730,10 +769,11 @@ class TimeSeriesPlotter:
         ch_list : list of integers
             List of indices of channels to be marked as 'bad'.
         """
+        # Update list of bad electrodes ids
         for ch in ch_list:
-            if ch not in self.badChannels:
-                self.badChannels.append(ch)
-        self.refreshScreen()
+            if ch not in self.bad_channels_ids:
+                self.bad_channels_ids.append(ch)
+        self.update_bad_channels()
 
     def BadChannelDel(self, ch_list):
         """
@@ -744,28 +784,32 @@ class TimeSeriesPlotter:
         ch_list : list of integers
             List of indices of channels to be un-marked as 'bad'.
         """
+        # Update list of bad electrodes ids
         for ch in ch_list:
-            if ch in self.badChannels:
-                self.badChannels.remove(ch)
-        self.refreshScreen()
+            if ch in self.bad_channels_ids:
+                self.bad_channels_ids.remove(ch)
+        self.update_bad_channels()
 
-    def BadChannelSave(self):
-        """Saves list of bad channels in current NWB file."""
-        buttonReply = QMessageBox.question(None, ' ', 'Save Bad Channels on current NWB file?',
-                                           QMessageBox.No | QMessageBox.Yes)
-        if buttonReply == QMessageBox.Yes:
-            # Modify current list of bad channels
-            aux = [False] * self.nChTotal
-            for ind in self.badChannels:
-                aux[ind] = True
-            if 'bad' not in self.nwb.electrodes:
-                self.nwb.add_electrode_column(
-                    name='bad',
-                    description='electrode identified as too noisy',
-                    data=aux,
-                )
-            else:
-                self.nwb.electrodes['bad'].data[:] = aux
+    def update_bad_channels(self):
+        """Updates list of bad channels after add or del"""
+        # List of electrodes IDs
+        elecs_ids = list(self.electrodes_table.id[:])
+        is_bad_list = [False] * len(elecs_ids)
+        for i, id in enumerate(elecs_ids):
+            if id in self.bad_channels_ids:
+                is_bad_list[i] = True
+
+        if 'bad' not in self.electrodes_table:
+            self.electrodes_table.add_column(
+                name='bad',
+                description='electrode identified as too noisy',
+                data=is_bad_list,
+            )
+        else:
+            self.electrodes_table['bad'].data[:] = is_bad_list
+
+        # Refresh screen
+        self.refreshScreen()
 
     def DrawMarkTime(self, position):
         """Marks temporary reference line when adding a new interval."""
